@@ -46,7 +46,7 @@ def extend_orfs(p = None, as_df = False, fasta_path = None, cds_id = None,
        chunk_size : the size to be extended on each direction. Default 900.
     """
 
-    # Sanity Check
+    # Sanity Checks
     assert p is not None, "Please, provide the path to a Pyranges instance."
 
     assert fasta_path is not None, "Please, provide the path to a Fasta file."
@@ -61,6 +61,23 @@ def extend_orfs(p = None, as_df = False, fasta_path = None, cds_id = None,
        msg = "Please, ensure all patterns have a length of 3 nt."
        assert set([len(i) for i in pattern]) == {3},msg
        
+    # Check if all input ranges are divisible by 3
+    p_df['length'] = p_df['End'] - p_df['Start'] 
+
+    # Compute module 3
+    p_df['module_3'] = p_df['length'] % 3
+
+    # Those not divisible by 3
+    ndv_df = p_df.loc[~p_df['module_3'].isin([0])]
+
+    if len(ndv_df.index) > 0: 
+        printerr("\nWARNING!\nSome input lenghts are not divisible by 3:\n",
+             how='bright,yellow')
+        printerr(ndv_df, how='bright,yellow')
+
+    # Drop unnecessary columns
+    p_df.drop(labels=['length','module_3'], inplace=True, axis=1)
+
     # So all subsequent steps can be done with group_by:
     if cds_id is None: 
         cds_id = 'Custom_ID'
